@@ -109,44 +109,44 @@ export const ConfigActionBar = ({
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    actionBarContainer: css`
-      display: flex;
-      flexdirection: row;
-      gap: ${theme.spacing(1)};
-      align-items: center;
-      justify-content: flex-end;
-    `,
-    iniFileLabel: css`
-      display: flex;
-      color: ${theme.colors.text.primary};
-      justify-content: flex-end;
-    `,
-    tooltipContainer: css`
-      padding: ${theme.spacing(0, 1)};
-    `,
-    statusContainer: css`
-      display: flex;
-      flex-direction: column;
-      font-size: ${theme.typography.bodySmall.fontSize};
-      border-left: 1px solid ${theme.colors.border.medium};
-      padding: ${theme.spacing(0, 2)};
-    `,
-    statusBadge: css`
-      span {
-        font-size: ${theme.typography.size.xs};
+    actionBarContainer: css({
+      display: 'flex',
+      flexDirection: 'row',
+      gap: theme.spacing(1),
+      alignItems: 'center',
+      justifyContent: 'flex-end',
+    }),
+    iniFileLabel: css({
+      display: 'flex',
+      color: theme.colors.text.primary,
+      justifyContent: 'flex-end',
+    }),
+    tooltipContainer: css({
+      padding: theme.spacing(0, 1),
+    }),
+    statusContainer: css({
+      display: 'flex',
+      flexDirection: 'column',
+      fontSize: theme.typography.bodySmall.fontSize,
+      borderLeft: `1px solid ${theme.colors.border.medium}`,
+      padding: theme.spacing(0, 2),
+    }),
+    statusBadge: css({
+      span: {
+        fontSize: theme.typography.size.xs,
       }
-    `,
-    statusLabel: css`
-      color: ${theme.colors.text.secondary};
-    `,
-    protocolContainer: css`
-      display: flex;
-      flex-direction: column;
-      font-size: ${theme.typography.bodySmall.fontSize};
-      padding-right: ${theme.spacing(1)};
-    `,
-    protocolLabel: css`
-      color: ${theme.colors.text.secondary};
-    `,
+    }),
+    statusLabel: css({
+      color: theme.colors.text.secondary,
+    }),
+    protocolContainer: css({
+      display: 'flex',
+      flexDirection: 'column',
+      fontSize: theme.typography.bodySmall.fontSize,
+      paddingRight: theme.spacing(1),
+    }),
+    protocolLabel: css({
+      color: theme.colors.text.secondary,
+    }),
   };
 };
